@@ -23,6 +23,9 @@ class SchemaObj(Subclassable, Dictifiable):
     field_types = dict()
 
     def __init__(self, **kwargs):
+        for key in self.field_types:
+            if key not in kwargs:
+                kwargs[key] = None
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -35,6 +38,8 @@ class SchemaObj(Subclassable, Dictifiable):
         deleted.
         '''
         super(SchemaObj, cls).__subclass__(**kwargs)
+        if callable(field_types):
+            field_types = field_types(cls)
         cls.field_types = overlay(cls.field_types, field_types)
         for key, field_or_dfier in cls.field_types.iteritems():
             cls.field_types[key] = Field.asfield(field_or_dfier)
@@ -73,7 +78,7 @@ class SchemaObj(Subclassable, Dictifiable):
     def __dictify__(self, **kwargs):
         result = {}
         for key, typ in self.field_types.items():
-            result[key] = typ.dictify(getattr(self, key))
+            result[key] = typ.dictify(getattr(self, key), **kwargs)
         return result
 
     def __validate__(self, **kwargs):
@@ -97,6 +102,20 @@ class SchemaObj(Subclassable, Dictifiable):
     def validate(self, **kwargs):
         return self.dfier().validate(self, **kwargs)
 
+    @classmethod
+    def sub_dfier_keys(cls, value=None):
+        return cls.field_types.keys()
+
+    @classmethod
+    def sub_dfier(cls, key, value=None):
+        return cls.field_types[key]
+
+    def __sub_value_keys__(self):
+        return self.sub_dfier_keys()
+
+    def __sub_value__(self, key):
+        return getattr(self, key, None)
+
 
 class DeclSchemaObj(SchemaObj):
     '''SchemaObj that automatically adds all Field class members to field_types.
